==> sems-0.8.12.tar.gz: sems-0.8.12/plug-in/stats/Statistics.cpp <==
/*
 * $Id: Statistics.cpp,v 1.1.2.2 2005/05/30 10:49:18 rco Exp $
 *
 * Copyright (C) 2002-2005 Fhg Fokus
 *
 * This file is part of sems, a free SIP media server.
 *
 * sems is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * For a license to use the sems software under conditions
 * other than those described here, or to purchase support for this
 * software, please contact iptel.org by e-mail at the following addresses:
 *    info@iptel.org
 *
 * sems is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "Statistics.h"
#include "StatsUDPServer.h"

#include "AmUtils.h"
#include "AmSession.h"
#include "SemsConfiguration.h"
#include "log.h"

#include <sys/types.h>
#include <sys/socket.h>

EXPORT_FACTORY(StatsFactory,"stats");

StatsFactory::StatsFactory(const string& _app_name)
    : AmStateFactory(_app_name)
{
}

AmDialogState* StatsFactory::onInvite(AmCmd& cmd)
{
    return NULL;
}

int StatsFactory::onLoad()
{
    sc = AmSessionContainer::instance();
    StatsUDPServer::instance()->start();
    return AmServer::instance()->registerFct("print_stats",this);
}


int StatsFactory::execute(FILE* stream, const string& cmd_str)
{
#define READ_PARAMETER(p)\
             READ_FIFO_PARAMETER(stream,p,line_buf,MAX_LINE_SIZE)

    string reply;
    string reply_fifo;
    char   line_buf[MAX_LINE_SIZE];

    READ_PARAMETER(reply_fifo);
    if(reply_fifo.empty())
	throw string("reply fifo parameter is empty");

    try {
	if(cmd_str == "calls")
	    reply = "Active calls: " + int2str(sc->getSize()) + "\n";
	else
	    throw string("unknown command: '" + cmd_str + "'");

	write_to_fifo(reply_fifo,reply.c_str(),reply.length());
    }
    catch(const string& err){
	string msg = err + "\n";
	write_to_fifo(reply_fifo,msg.c_str(),msg.length());
	return -1;
    }

    return 0;

#undef READ_PARAMETER
}

==> sems-0.9.0.tar.gz: sems-0.9.0/plug-in/stats/Statistics.cpp <==
/*
 * $Id: Statistics.cpp,v 1.2 2005/01/30 12:43:50 rco Exp $
 *
 * Copyright (C) 2002-2005 Fhg Fokus
 *
 * This file is part of sems, a free SIP media server.
 *
 * sems is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * For a license to use the sems software under conditions
 * other than those described here, or to purchase support for this
 * software, please contact iptel.org by e-mail at the following addresses:
 *    info@iptel.org
 *
 * sems is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "Statistics.h"

#include "AmUtils.h"
#include "AmSession.h"
#include "SerClient.h"
#include "log.h"

EXPORT_FACTORY(StatsFactory,"stats");

StatsFactory::StatsFactory(const string& _app_name)
    : AmStateFactory(_app_name)
{
}

AmDialogState* StatsFactory::onInvite(AmCmd& cmd)
{
    return NULL;
}

int StatsFactory::onLoad()
{
    sc = AmSessionContainer::instance();
    return AmFifoServer::instance()->registerFct("print_stats",this);
}


int StatsFactory::execute(FILE* stream, const string& cmd_str)
{
#define READ_PARAMETER(p)\
             READ_FIFO_PARAMETER(stream,p,line_buf,MAX_LINE_SIZE)

    string reply;
    string reply_fifo;
    char   line_buf[MAX_LINE_SIZE];

    READ_PARAMETER(reply_fifo);
    if(reply_fifo.empty())
	throw string("reply fifo parameter is empty");

    try {
	if(cmd_str == "calls")
	    reply = "Active calls: " + int2str(sc->getSize()) + "\n";
	else
	    throw string("unknown command: '" + cmd_str + "'");

	write_to_fifo(reply_fifo,reply.c_str(),reply.length());
    }
    catch(const string& err){
	string msg = err + "\n";
	write_to_fifo(reply_fifo,msg.c_str(),msg.length());
	return -1;
    }

    return 0;

#undef READ_PARAMETER
}
